@@ -13,9 +13,10 @@ pvx.matrix<-function(theta_v,thres,xm_v=NULL){
   px_v <- mapply(FUN=function(o,u){  o / u }, o=as.list(as.data.frame(oben_v)), u=as.list(unten_v) ) # u as list etc --> korrigiert am 10-3-2015 # ok - für theta_v als vector oder zahl 
   rownames(px_v)<-paste("cat",0:(length(thres0)-1),sep=".") 
   colnames(px_v)<-theta_v 
-  P_v <- apply(px_v,2,sum) # ok - für theta_v als vector oder zahl
-  if(length(xm_v)==0){return( (px_v) )}
-  if(length(xm_v)!=0){mapply(function(p,ic){p[ic]}, as.list(as.data.frame(px_v)), xm_v)}
+  P_v <- apply(px_v,2,sum) # ok - für theta_v als vector oder zahl kontrolle alle 1
+  if(length(xm_v)==0){erg <-(px_v)}
+  if(length(xm_v)!=0){erg <- mapply(function(p,ic){p[ic]}, p=(as.list(as.data.frame(px_v))), ic=(xm_v+1))}
+  return(erg)
 }     
 #---------------------------------------------------  
 
